---
title: <span class="badge object-type-scalar"></span> Becquerel
---
# <span class="badge object-type-scalar"></span> Becquerel

Radiation: Becquerel (Bq)

## Definition

```python
# Radiation: Becquerel (Bq)
Becquerel: typing.Literal["radbq"] = "radbq"
```
